package com.john.testlog;

import android.util.Log;

public class MyLogger {
//	private static final String TAG = "MyLogger";
	/**  是否输出Log信息   */
	public static boolean DEBUG = true;

	/**  设置显示Log的级别   */
	public static int SHOW_LEVEL = Level.ALL;
	
	/**
	 * Log级别类
	 * @date 2014-10-20 上午10:06:55
	 * @author JohnWatson
	 * @version 1
	 */
	public static class Level{
		/** 显示所有级别 */
		public static int ALL = 0;
		/** 显示v级别 */
		public static int VERBOSE = 1;
		/** 显示d级别 */
		public static int DEBUG = 2;
		/** 显示i级别 */
		public static int INFO = 3;
		/** 显示w级别 */
		public static int WARN = 4;
		/** 显示e级别 */
		public static int ERROR = 5;
		/** 不显示任何级别 */
		public static int NONE = 6;
	}
	
	/**
	 * 显示Log信息（带行号）
	 * @param logLevel 1 v ; 2 d ; 3 i ; 4 w ; 5 e .
	 * @param info 显示的log信息
	 * @date 2014-8-22 上午9:34:15
	 * @author JohnWatson
	 * @version 1.0
	 */
	public static void showLogWithLineNum(int logLevel, String info) {
		
		if (!DEBUG || (logLevel < SHOW_LEVEL)) return;
		
		String[] infos = getAutoJumpLogInfos();

		switch (logLevel) {
		case 1:
			Log.v(infos[0], info + " : " + infos[1] + infos[2]);				
			break;
		case 2:
			Log.d(infos[0], info + " : " + infos[1] + infos[2]);
			break;
		case 3:
			Log.i(infos[0], info + " : " + infos[1] + infos[2]);
			break;
		case 4:
			Log.w(infos[0], info + " : " + infos[1] + infos[2]);
			break;
		case 5:
			Log.e(infos[0], info + " : " + infos[1] + infos[2]);
			break;
		default:
			Log.w(infos[0], info + " : " + infos[1] + infos[2]);
			break;
		}
	}
	
	/**
	 * 获取打印信息所在方法名，行号等信息
	 * @return 
	 * @date 2014-8-22 上午9:33:58
	 * @author JohnWatson
	 * @version 1.0
	 */
	private static String[] getAutoJumpLogInfos() {
		String[] infos = new String[] { "", "", "" };
		StackTraceElement[] elements = Thread.currentThread().getStackTrace();
		if (elements.length < 5) {
			Log.e("MyLogger", "Stack is too shallow!!!");
			return infos;
		} else {
			infos[0] = elements[4].getClassName().substring(
					elements[4].getClassName().lastIndexOf(".") + 1);
			infos[1] = elements[4].getMethodName() + "()";
			infos[2] = " at (" + elements[4].getClassName() + ".java:"
					+ elements[4].getLineNumber() + ")";
			return infos;
		}
	}
}
